@@ -57,6 +57,7 @@ class MMActuator(QObject):
 
         self.event_bus = event_bus
         self.studio = event_bus.studio
+        self.core = event_bus.event_thread.bridge.get_core()
         self.interval = 5
         self.acquisition = None
         self.acquisition_mode = (
@@ -424,7 +425,13 @@ class TimerMMAcquisition(MMAcquisition):
         return self.calibrated_wait_time
 
     def _ramp_calibration(self, wait_time, step, settings):
+
         custom_int = settings.custom_intervals_ms()
+        if custom_int is None:
+            log.warning(
+                "Add any number of custom intervals in Micro-Manager and restart please"
+            )
+
         custom_int.clear()
         custom_int.add(1500)
         custom_int.add(0)
